xsdata.models package
=====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.models.enums
   xsdata.models.mixins
   xsdata.models.xsd

Module contents
---------------

.. automodule:: xsdata.models
   :members:
   :undoc-members:
   :show-inheritance:
